@@ -18,6 +18,13 @@ App::sdif::colors
 
 Read `perldoc -m App::sdif::colors` to see the actual definition.
 
+Option B<--light> or B<--dark> is set by B<-Mautocolor> module
+according to the brightness of the terminal screen.  You can override
+them in your F<~/.sdifrc> like:
+
+    option --light --cmy
+    option --dark  --dark-cmy
+
 =head1 SEE ALSO
 
 L<App::sdif::autocolor>,
@@ -68,7 +75,7 @@ option	--mono \
 	--cm    ?LINE=222	\
 	--cm    ?TEXT=000/L23	\
 	--cm    UTEXT=111	\
-	--cdifopts ' --mono '
+	--cdifopts='--mono'
 
 define {DARK_BG1} L10
 define {DARK_BG2} L04
@@ -84,7 +91,7 @@ option	--dark-green \
 	--cm ?COMMAND=K/232;		\
 	--cm    ?FILE=K/232;D		\
 	--cm    ?LINE=220		\
-	--cdifopts ' --dark-green '
+	--cdifopts='--dark-green'
 
 option	--dark-cmy \
 	--dark-screen			\
@@ -95,14 +102,14 @@ option	--dark-cmy \
 	--cm MCOMMAND=K/332		\
 	--cm    MFILE=K/332;D		\
 	--cm    ?LINE=220		\
-	--cdifopts ' --dark-cmy '
+	--cdifopts='--dark-cmy'
 
 option	--dark-mono \
 	--dark-screen			\
 	--cm ?COMMAND=/{DARK_BG1}	\
 	--cm    ?FILE=D/{DARK_BG1}	\
 	--cm    ?LINE=111		\
-	--cdifopts ' --dark-mono '
+	--cdifopts='--dark-mono'
 
 ##
 ## for backward compatinbility
